Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'doc/python_api/examples/mathutils.Color.py')
-rw-r--r--doc/python_api/examples/mathutils.Color.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/doc/python_api/examples/mathutils.Color.py b/doc/python_api/examples/mathutils.Color.py
index a55f1195bf6..cedda98ae53 100644
--- a/doc/python_api/examples/mathutils.Color.py
+++ b/doc/python_api/examples/mathutils.Color.py
@@ -26,5 +26,5 @@ col += mathutils.Color((0.25, 0.0, 0.0))
# can printed as integers
print("Color: %d, %d, %d" % (col * 255.0)[:])
-# This example prints the color as hexidecimal
-print("Hexidecimal: %.2x%.2x%.2x" % (col * 255.0)[:])
+# This example prints the color as hexadecimal
+print("Hexadecimal: %.2x%.2x%.2x" % (col * 255.0)[:])